// license:BSD-3-Clause
// copyright-holders:Fabrice Bellet
//
// https://github.com/Sebastus1976/Amadeus

#include "emu.h"
#include "amadeus.h"

#include "sound/ymopl.h"
#include "sound/sn76496.h"
#include "speaker.h"

// device type definition
DEFINE_DEVICE_TYPE(THOMSON_AMADEUS, thomson_amadeus_device, "thomson_amadeus", "Homebrew sound card")

//-------------------------------------------------
//  thomson_amadeus_device - constructor
//-------------------------------------------------

thomson_amadeus_device::thomson_amadeus_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock)
	: device_t(mconfig, THOMSON_AMADEUS, tag, owner, clock)
	, thomson_extension_interface(mconfig, *this)
{
}

void thomson_amadeus_device::rom_map(address_map &map)
{
}

void thomson_amadeus_device::io_map(address_map &map)
{
	map(0x3c, 0x3d).rw("ym2413", FUNC(ym2413_device::read), FUNC(ym2413_device::write));
	map(0x3f, 0x3f).w("sn76496", FUNC(sn76496_device::write)); // alternate config is 0x37
}

void thomson_amadeus_device::device_add_mconfig(machine_config &config)
{
	ym2413_device &ym2413(YM2413(config, "ym2413", 3579545));
	ym2413.add_route(ALL_OUTPUTS, "speaker", 0.5);

	sn76496_device &sn76496(SN76496(config, "sn76496", 3579545));
	sn76496.add_route(ALL_OUTPUTS, "speaker", 0.5);

	// FIXME: actually drives main speaker through the sound line on the bus
	SPEAKER(config, "speaker").front_center();
}

void thomson_amadeus_device::device_start()
{
}
